TopoFlags

Struct TopoFlags 

pub struct TopoFlags(pub(crate) u8);
Flags that define the properties of segments and edges.

Tuple Fields

0: u8

Implementations

Source

impl TopoFlags

pub const NORMAL: Self

Regular segment or edge.

pub const ROUND: Self

Segment or edge has rounded geometry.

pub const SERIF: Self

Segment or edge represents a serif.

pub const DONE: Self

Segment or edge has been successfully processed.

pub const NEUTRAL: Self

Segment or edge aligns to a neutral blue zone.

Source

impl TopoFlags

pub const fn from_bits_truncate(bits: u8) -> Self

Creates new flags, truncating the given bits to valid values.

pub const fn to_bits(self) -> u8

Returns the underlying flag bits.

pub const fn contains(self, other: Self) -> bool

Returns true if self contains all flags in other.

pub const fn intersects(self, other: Self) -> bool

Returns true if self contains any flags in other.